# -*- coding: UTF-8 -*-
import unittest


class MyTest(unittest.TestCase):  # 继承unittest.TestCase
    def tearDown(self):
        # 每个测试用例执行之后做操作
        print('22222222-----------over--------------')

    def setUp(self):
        # 每个测试用例执行之前做操作
        print('11111111-----------begin-------------')

    @classmethod
    def tearDownClass(self):
        # 必须使用 @ classmethod装饰器, 所有test运行完后运行一次
        pass

    @classmethod
    def setUpClass(self):
        # 必须使用@classmethod 装饰器,所有test运行前运行一次
        import model
        self.model = model.Model()

    # 测试创建一条新任务
    # def test_save_one(self):
    #     #.\hitc.exe model create -n first_modelv1.0 -t detection -j .\model_v2.10.2.json -p .\model_v2.10.2.params --dept aiot --perm private
    #     # name = "first_modelv1.%s"%(random.randint(1,3))
    #     name = "first_modelv1.94"
    #     task_type = "detection"
    #     # task_type = ""
    #     json_path = "C:\\Users\\v-yu.gao\\goworkpath\\olympus\\app\\cmd\\model_v2.10.2.json"
    #     param_path = "C:\\Users\\v-yu.gao\\goworkpath\\olympus\\app\\cmd\\model_v2.10.2.params"
    #     dept = "aiot"
    #     level = "public"

    #     print(self.model.save_one(name, task_type, json_path, param_path, dept, level))    

    # 测试追加一条已经有的任务，需要指定nid
    # def test_append_one(self):
    #     idx = 224
    #     json_path = "C:\\Users\\v-yu.gao\\goworkpath\\olympus\\app\\cmd\\model_v2.10.2.json"
    #     param_path = "C:\\Users\\v-yu.gao\\goworkpath\\olympus\\app\\cmd\\model_v2.10.2.params"

    #     print(self.model.append_one(nid, json_path, param_path))    

    # 测试创建任务--多版本
    # def test_save(self):
    #     name = "first_modelv1.98"
    #     task_type = "detection"
    #     # task_type = ""
    #     json_path = "C:\\Users\\v-yu.gao\\goworkpath\\olympus\\app\\cmd\\model_v2.10.2.json"
    #     param_path = "C:\\Users\\v-yu.gao\\goworkpath\\olympus\\app\\cmd\\model_v2.10.2.params"
    #     dept = "aiot"
    #     level = "public"


    #     json_paths = []
    #     param_paths = []

    #     for x in range(3):
    #         json_paths.append(json_path)
    #         param_paths.append(param_path)

    #     print(self.model.save(name, task_type, json_paths, param_paths, dept, level))


    def test_download(self):
        idx = 224
        print(self.model.download(224))

if __name__ == '__main__':
    unittest.main()#运行所有的测试用例



# coding=utf-8
from __future__ import print_function

import os
import sys
import re

import time
import json
import platform
import requests

from .utils import hitc


class Model(object):
    def __init__(self):
        super(Model, self).__init__()

    # 创建模型目录和添加初始版本
    def save_one(self, name, task_type, json_path, param_path, dept, level):
        command = [
            "model", "create", "-n", name, "-t", task_type, "-j", json_path,
            "-p", param_path, "--dept", dept, "--perm", level
        ]
        # success, created gpu model dir's id is 237
        return hitc(command)

    # 给已存在的模型目录添加版本
    def append_one(self, parent_id, json_path, param_path):
        command = [
            "model", "append", "--id",
            str(parent_id), "-j", json_path, "-p", param_path
        ]
        return hitc(command)

    # 创建模型目录添加初始版本，并通过append命令添加后续的版本
    def save(self, name, task_type, json_paths, param_paths, dept, level):
        result = []
        begin = 0
        parent_id = None

        res = self.save_one(name, task_type, json_paths[0], param_paths[0],
                            dept, level)

        if res.startswith("success") and re.search(r'\d+', res):
            # success, created gpu model dir's id is 237"
            parent_id = re.search(r'\d+', res).group()

            begin = 1
            result.append('succeed : {} {} {} {} {} {}'.format(
                name, task_type, json_paths[0], param_paths[0], dept, level))

        # model create failed, error: GPU model name already exist.
        elif re.search("name already exist", res):
            begin = 0


        for json_path, param_path in zip(json_paths[begin:],
                                         param_paths[begin:]):
            if parent_id:

                res = self.append_one(parent_id, json_path, param_path)

                if not res.startswith("success"):
                    result.append('failed : {} {} {} {} {} {}'.format(
                        name, task_type, json_path, param_path, dept, level))

                else:
                    result.append('succeed : {} {} {} {} {} {}'.format(
                        name, task_type, json_path, param_path, dept, level))

        return result

    # 模型下载
    def download(self, idx):
        # model download --id
        command = ["model", "download", "--id", str(idx)]

        res = hitc(command)
        if res.startswith("model get failed"):
            print (res)
            return None

        elif res.startswith(
                "panic: interface conversion: interface {} is nil"):
            print (res)
            return None

        else:
            print("download model id %s " % str(idx))
            return True

    # 算法模型单条删除
    def delete(self, idx):
        # Are you sure to delete gpu model dir:  first_modelv1.6
        # y/n?
        # yes
        # success
        if not isinstance(idx, int):
            print("id :%s is error" % idx)
            return

        res = hitc(["model", "delete", "--help"])  # .stdout.read()
        # res = hitcx(["model", "delete", "-k", str(idx)])#.stdout.read()
        # print (dir(res))
        # print (res.stdout.read())
        # p.stdin.flush()
        print(res)
        # if res.startswith("Are you sure to delete gpu model"):
        #     print ("????????")
        #     # return hitc(["yes"])
        # else:
        return res



# -*- coding: UTF-8 -*-

import os
import platform
from .utils import hitc
from .setting import HITC_PATH

# 从容器环境变量中初始化相关信息
# md5 = os.getenv("MD5")
# # 当前登录用户的ID
# uid = os.getenv("UID")
# # 当前登录用户的用户名
# uname = os.getenv("UName")
# # gateway地址
# url = os.getenv("gateway_url")
# # 训练Job的ID
# job_id = os.getenv("jobId")
# # 训练Job所属的ProjectID
# project_id = os.getenv("projectId")
# # 训练生成的模型文件在GlusterFS上的绝对路径
# host_path = os.getenv("py_hostpath")
# # 训练生成的模型文件在容器内的相对路径
# container_path = os.getenv("py_containerpath")


def check_login():
    command = ["who"]
    res = hitc(command)
    ## Get login user info error:
    if res.startswith("You are not login"):
        command = ["login"]
        res = hitc(command)
    # print (res)


if HITC_PATH:
    check_login()


# coding=utf-8

import os
import platform

# 从容器环境变量中初始化相关信息
md5 = os.getenv("MD5")
# 当前登录用户的ID
uid = os.getenv("UID")
# 当前登录用户的用户名
uname = os.getenv("UName")
# gateway地址
url = os.getenv("gateway_url")
# 训练Job的ID
job_id = os.getenv("jobId")
# 训练Job所属的ProjectID
project_id = os.getenv("projectId")
# 训练生成的模型文件在GlusterFS上的绝对路径
host_path = os.getenv("py_hostpath")
# 训练生成的模型文件在容器内的相对路径
container_path = os.getenv("py_containerpath")


def search_hitc_path():
    plm = platform.system()

    if plm == "Windows":

        env_dist = os.environ["Path"].split(";")
     
        for st in env_dist:

            if os.path.exists(st) and os.path.isdir(st):
                if "hitc.exe" in os.listdir(st):
                    print ("check you hitc.exe exist!".upper())
                    return os.path.join(st,"hitc.exe")

        print ("please append you hitc on you Windows system Path".upper())

    else:
        env_dist = os.environ["PATH"].split(":")
     
        for st in env_dist:
            if os.path.exists(st) and os.path.isdir(st):
                if "hitc" in os.listdir(st):
                    print ("check you hitc exist!".upper())
                    return os.path.join(st,"hitc")

        print ("please append you hitc on you Linux system Path".upper())
    return None


HITC_PATH = search_hitc_path()




# coding=utf-8
from __future__ import print_function

import requests
import os
import time
import json
import sys

from utils import hitc


class Report(object):
    def __init__(self):
        super(Report, self).__init__()

    def create(self, configFile):
        res = self._do_eval(configFile)
        return res

    # 任务执行
    def _do_eval(self, configFile):
        #./hitc evalreport create -f report_config_file
        command = ["evalreport", "create", "-f %s"%configFile]  
        return hitc(command)
    

# 创建评测报告
# config_file_path: 评测报告配置文件
# profile_id: 评测代码包的ID
# params_ids: 评测参数的ID列表，可以设置多个
# images_dataset_id: Dataspace中dataset的ID
# gt_dataset_id: Dataspace中gt的ID
# pr_dataset_id: Dataspace中pr的ID
# dept: 模型所属的部门名称 支持 auto aiot platform
# level: 模型资源的权限级别，支持 private public
# 返回空表明创建成功，返回非空表示创建失败，返回的信息为失败原因
def create_eval_report(config_file_path, dept, level):
    res = _do_eval(name, algo_task_type_id, profile_id, params_ids,
                   images_dataset_id, gt_dataset_id, pr_dataset_id, dept,
                   level)
    if res.get("code") != 0:
        return res.get("err_user_msg")
    return ""


def _do_eval(name, algo_task_type_id, profile_id, params_ids,
             images_dataset_id, gt_dataset_id, pr_dataset_id, dept, level):
    payload = {
        "name": name,
        "algo_task_type_id": algo_task_type_id,
        "profile_id": profile_id,
        "params_ids": params_ids,
        "images_dataset_id": images_dataset_id,
        "gt_dataset_id": gt_dataset_id,
        "pr_dataset_id": pr_dataset_id,
        "auth_info": {
            "level": level,
            "deptid": dept
        }
    }
    print(payload)
    r = requests.post("http://" + url + "/api/evaluation/v1/val-task",
                      json=payload,
                      headers={"Digest": md5, "uid": uid, "uname": uname})
    print(r)
    print(r.json())
    return r.json()


#!/usr/bin/env python
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: gaoyu
# Mail: xiangqukk@163.com
# Created Time:  2019-8-26
#############################################


from setuptools import setup, find_packages  
#这个包没有的可以pip一下

with open('README.rst', encoding='UTF-8') as f:
    readme = f.read()

with open('LICENSE', encoding='UTF-8') as f:
    license = f.read()

setup(
    name = "olympus-hitc",      #这里是pip项目发布的名称
    version = "0.0.8",  #版本号，数值大的会优先被pip
    keywords = ["pip", "olympus","hitc"],
    description = "an api of project olympus",
    license = license,

    url = "http://gitlab.hobot.cc/ptd/ap/toolchain/ai-platform/olympus/tree/dev/python",     #项目相关文件地址，一般是github
    author = "gaoyu",
    author_email = "xiangqukk@163.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires = ["requests"]          #这个项目需要的第三方库
)



# coding=utf-8
import os
import sys
import subprocess
import platform


def _platform():
    hitc_path = {
        "Windows": "hitc.exe",
        "Linux": "hitc"
    }

    return hitc_path.get(platform.system(), "hitc")


def _hitc():
    hitc_path = _platform()
    
    def hitc_subprocess(xargs):
        xargs.insert(0, hitc_path)
        xargs = " ".join(xargs)

        child1 = subprocess.Popen(xargs,
                                  stdin=subprocess.PIPE,
                                  stdout=subprocess.PIPE,
                                  shell=True,
                                  universal_newlines=True)

        # 非阻塞
        return child1.stdout.read()

    return hitc_subprocess




def _hitc_block():
    hitc_path =_platform()

    def hitc_subprocess(xargs):
        xargs.insert(0, hitc_path)
        xargs = " ".join(xargs)

        child1 = subprocess.Popen(xargs,
                                  stdin=subprocess.PIPE,
                                  stdout=subprocess.PIPE,
                                  shell=True,
                                  universal_newlines=True)

        # # 阻塞
        result = child1.communicate(input=None)
        # ('model create failed, error:nGPU model name already exist.\n', None)
        return result[0]

    return hitc_subprocess


hitc = _hitc_block()
hitc_block = _hitc_block()

# if __name__ == "__main__":
#     hitc(["-a","-b","-c"])
